@@ -1,4 +1,5 @@
-#pragma once
+#ifndef RPGM_REXP
+#define RPGM_REXP
 
 #include <R.h>
 #include <Rinternals.h>
@@ -7,7 +8,13 @@
 
 void rexp_vect(int N, double * vector, SEXP * lambda);
 void rexp_rpgm(int N, double * vector, double inv_lambda);
+extern "C" 
+{
 SEXP re(SEXP n, SEXP lambda);
+}
 void rgeom_rpgm(int N, int * vector, double p);
+extern "C" 
+{
 SEXP rg(SEXP n, SEXP p);
-
+}
+#endif
